» Parse.ly Press Coverage – August 2013
Author: http://www.pixelmonkey.org/author/pixelmonkey
Description: Parse.ly made its funding announcement -- a $5M series A, led by Grotech Ventures and with participation from FundersClub, Blumberg Capital, and ff Venture Capital. Read on for the full list of lin...
Date: 2013-09-03T17:53:22+00:00

home photos about me contact

## Parse.ly Press Coverage – August 2013

Parse.ly made its funding announcement — a $5M series A, led by Grotech Ventures and with participation from FundersClub, Blumberg Capital, and ff Venture Capital. Read on for the full list of links to our coverage.

Here is some coverage from around the web:

- TechCrunch: Parse.ly Raises $5M For Predictive Analytics Platform That Helps Media Companies Decide What To Publish
- MediaPost: Parse.ly Raises $5 Million, Invests In Core Tech, Data
- The Daily Startup @ Wall Street Journal, VC Dispatch
- Washington Business Journal: Grotech leads $5 million round in analytics startup Parse.ly
- MarketingLand: Facebook Driving More Than 2x Twitter Traffic To Parse.ly’s News Clients
- GigaOM: Feedly dominating the post-Reader world, and other web-publishing insights from Parse.ly
- peHUB: Parse.ly raises $5M
- Parse.ly Blog: Parse.ly Investors Back the New Content Performance Authority
- The Next Web: A month after Google Reader vanishes, Feedly ranks as the top RSS traffic referrer
- VentureBeat: Parse.ly nabs $5 million to continue getting you to click on Grumpy Cat
- PSFK: Platform Tells Bloggers What To Write About Next [Video]
- memeburn: Life after Google Reader: yes, Feedly is still winning
- Brafton: Yahoo might be top web property, but Google still drives most traffic
- eMediaVitals: Publishing analytics startup Parse.ly releases first report on traffic drivers
- IPG Media Lab: Parse.ly Does Intelligent Tagging
- ContentStandard: Parse.ly Delivers Content Optimization for Online Publishers

More coming soon!

Andrew Montalenti (aka pixelmonkey, amontalenti) is the co-founder and CTO of Parse.ly, which provides data insights to the web's best publishers. You can follow him on Twitter or LinkedIn. If you liked this post, you should subscribe to his free e-mail newsletter, Fire and Motion, which discusses technology startups and business from the trenches. This entry was posted on Tuesday, September 3rd, 2013 at 12:53 pm and is filed under Startups, Technology, Uncategorized. You can follow any responses to this entry through the RSS 2.0 feed. You can leave a response, or trackback from your own site.

### Leave a Reply

Name (required)

Mail (will not be published) (required)

Website

Notify me of follow-up comments by email.

Notify me of new posts by email.